==> zio-aws-timestreamwrite_3-5.17.129.2-sources.jar: zio/aws/timestreamwrite/model/package.scala <==
package zio.aws.timestreamwrite
import zio.aws.timestreamwrite.model.primitives.TagKey
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.timestreamwrite.model.primitives.Date.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.timestreamwrite.model.primitives.AmazonResourceName.Type
    object Date extends Subtype[Instant]
    type Date = zio.aws.timestreamwrite.model.primitives.Date.Type
    object Integer extends Subtype[Int]
    type Integer = zio.aws.timestreamwrite.model.primitives.Integer.Type
    object MagneticStoreRetentionPeriodInDays extends Subtype[Long]
    type MagneticStoreRetentionPeriodInDays =
      zio.aws.timestreamwrite.model.primitives.MagneticStoreRetentionPeriodInDays.Type
    object MemoryStoreRetentionPeriodInHours extends Subtype[Long]
    type MemoryStoreRetentionPeriodInHours =
      zio.aws.timestreamwrite.model.primitives.MemoryStoreRetentionPeriodInHours.Type
    object PaginationLimit extends Subtype[Int]
    type PaginationLimit =
      zio.aws.timestreamwrite.model.primitives.PaginationLimit.Type
    object RecordVersion extends Subtype[Long]
    type RecordVersion =
      zio.aws.timestreamwrite.model.primitives.RecordVersion.Type
    object ResourceCreateAPIName extends Subtype[String]
    type ResourceCreateAPIName =
      zio.aws.timestreamwrite.model.primitives.ResourceCreateAPIName.Type
    object ResourceName extends Subtype[String]
    type ResourceName =
      zio.aws.timestreamwrite.model.primitives.ResourceName.Type
    object S3BucketName extends Subtype[String]
    type S3BucketName =
      zio.aws.timestreamwrite.model.primitives.S3BucketName.Type
    object S3ObjectKeyPrefix extends Subtype[String]
    type S3ObjectKeyPrefix =
      zio.aws.timestreamwrite.model.primitives.S3ObjectKeyPrefix.Type
    object SchemaName extends Subtype[String]
    type SchemaName = zio.aws.timestreamwrite.model.primitives.SchemaName.Type
    object SchemaValue extends Subtype[String]
    type SchemaValue = zio.aws.timestreamwrite.model.primitives.SchemaValue.Type
    object StringValue2048 extends Subtype[String]
    type StringValue2048 =
      zio.aws.timestreamwrite.model.primitives.StringValue2048.Type
    object StringValue256 extends Subtype[String]
    type StringValue256 =
      zio.aws.timestreamwrite.model.primitives.StringValue256.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.timestreamwrite.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.timestreamwrite.model.primitives.TagValue.Type
  }
  type DatabaseList = List[zio.aws.timestreamwrite.model.Database]
  type Dimensions = List[zio.aws.timestreamwrite.model.Dimension]
  type Endpoints = List[zio.aws.timestreamwrite.model.Endpoint]
  type MeasureValues = List[zio.aws.timestreamwrite.model.MeasureValue]
  type Records = List[zio.aws.timestreamwrite.model.Record]
  type TableList = List[zio.aws.timestreamwrite.model.Table]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.timestreamwrite.model.Tag]
}

==> zio-aws-timestreamwrite_3-5.17.203.2-sources.jar: zio/aws/timestreamwrite/model/package.scala <==
package zio.aws.timestreamwrite
import zio.aws.timestreamwrite.model.primitives.TagKey
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.timestreamwrite.model.primitives.Date.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.timestreamwrite.model.primitives.AmazonResourceName.Type
    object Date extends Subtype[Instant]
    type Date = zio.aws.timestreamwrite.model.primitives.Date.Type
    type Integer = Int
    object MagneticStoreRetentionPeriodInDays extends Subtype[Long]
    type MagneticStoreRetentionPeriodInDays =
      zio.aws.timestreamwrite.model.primitives.MagneticStoreRetentionPeriodInDays.Type
    object MemoryStoreRetentionPeriodInHours extends Subtype[Long]
    type MemoryStoreRetentionPeriodInHours =
      zio.aws.timestreamwrite.model.primitives.MemoryStoreRetentionPeriodInHours.Type
    object PaginationLimit extends Subtype[Int]
    type PaginationLimit =
      zio.aws.timestreamwrite.model.primitives.PaginationLimit.Type
    object RecordVersion extends Subtype[Long]
    type RecordVersion =
      zio.aws.timestreamwrite.model.primitives.RecordVersion.Type
    object ResourceCreateAPIName extends Subtype[String]
    type ResourceCreateAPIName =
      zio.aws.timestreamwrite.model.primitives.ResourceCreateAPIName.Type
    object ResourceName extends Subtype[String]
    type ResourceName =
      zio.aws.timestreamwrite.model.primitives.ResourceName.Type
    object S3BucketName extends Subtype[String]
    type S3BucketName =
      zio.aws.timestreamwrite.model.primitives.S3BucketName.Type
    object S3ObjectKeyPrefix extends Subtype[String]
    type S3ObjectKeyPrefix =
      zio.aws.timestreamwrite.model.primitives.S3ObjectKeyPrefix.Type
    object SchemaName extends Subtype[String]
    type SchemaName = zio.aws.timestreamwrite.model.primitives.SchemaName.Type
    object SchemaValue extends Subtype[String]
    type SchemaValue = zio.aws.timestreamwrite.model.primitives.SchemaValue.Type
    object StringValue2048 extends Subtype[String]
    type StringValue2048 =
      zio.aws.timestreamwrite.model.primitives.StringValue2048.Type
    object StringValue256 extends Subtype[String]
    type StringValue256 =
      zio.aws.timestreamwrite.model.primitives.StringValue256.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.timestreamwrite.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.timestreamwrite.model.primitives.TagValue.Type
  }
  type DatabaseList = List[zio.aws.timestreamwrite.model.Database]
  type Dimensions = List[zio.aws.timestreamwrite.model.Dimension]
  type Endpoints = List[zio.aws.timestreamwrite.model.Endpoint]
  type MeasureValues = List[zio.aws.timestreamwrite.model.MeasureValue]
  type Records = List[zio.aws.timestreamwrite.model.Record]
  type TableList = List[zio.aws.timestreamwrite.model.Table]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.timestreamwrite.model.Tag]
}
